#Bubot Helper

Helper for modules of the boobot framework

## Licensing

This published under the MIT License, see LICENSE for details.


Copyright (c) 2019 Mikhail Razgovorov <http://razgovorov.ru/>,
